IceObject

Trait IceObject 

pub trait IceObject {
    // Required methods
    fn ice_ping<'life0, 'async_trait>(
        &'life0 mut self,
    ) -> Pin<Box<dyn Future<Output = Result<(), Box<dyn Error + Sync + Send>>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn ice_is_a<'life0, 'async_trait>(
        &'life0 mut self,
    ) -> Pin<Box<dyn Future<Output = Result<bool, Box<dyn Error + Sync + Send>>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn ice_id<'life0, 'async_trait>(
        &'life0 mut self,
    ) -> Pin<Box<dyn Future<Output = Result<String, Box<dyn Error + Sync + Send>>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn ice_ids<'life0, 'async_trait>(
        &'life0 mut self,
    ) -> Pin<Box<dyn Future<Output = Result<Vec<String>, Box<dyn Error + Sync + Send>>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
}
The IceObject trait is a base trait for all ice interfaces. It implements functions that are equal to all ice interfaces.

Required Methods

fn ice_ping<'life0, 'async_trait>( &'life0 mut self, ) -> Pin<Box<dyn Future<Output = Result<(), Box<dyn Error + Sync + Send>>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn ice_is_a<'life0, 'async_trait>( &'life0 mut self, ) -> Pin<Box<dyn Future<Output = Result<bool, Box<dyn Error + Sync + Send>>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn ice_id<'life0, 'async_trait>( &'life0 mut self, ) -> Pin<Box<dyn Future<Output = Result<String, Box<dyn Error + Sync + Send>>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn ice_ids<'life0, 'async_trait>( &'life0 mut self, ) -> Pin<Box<dyn Future<Output = Result<Vec<String>, Box<dyn Error + Sync + Send>>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Implementors